@@ -3,6 +3,7 @@ from typing import Optional
 from uuid import uuid4
 import logging
 
+import pymongo
 from motor.motor_asyncio import AsyncIOMotorClient
 
 import bson.errors
@@ -212,13 +213,17 @@ class MongoODMBase(MongODMBaseModel):
         page: int = 1,
         per_page: int = 20,
         selector: dict = None,
+        sort: dict = None,
         **kwargs,
     ) -> list:  # -> List[Self]
         if selector is None:
             selector = kwargs
+        if sort is None:
+            sort = [("created_at", pymongo.DESCENDING)]
         selector = cls.replace_str_with_object_id(selector)
         items = await config['database_connection'][config['database_name']][cls.__collection_name__]\
             .find(cls._get_fetch_filter(selector))\
+            .sort(sort)\
             .skip((page - 1) * per_page)\
             .limit(per_page)\
             .to_list(length=None)
@@ -237,17 +242,21 @@ class MongoODMBase(MongODMBaseModel):
         return payload
 
     async def save(self, exclude_none=False, exclude_unset=False):  # -> Self
+        create = False
         if self.id is None:
+            create = True
             return await self._create()
         await self.before_save()
         self.updated_at = datetime.now()
         payload = self._get_dict_with_oid(exclude=True, exclude_none=exclude_none, exclude_unset=exclude_unset)
-        payload = await self.before_update(payload)
+        if not create:
+            payload = await self.before_update(payload)
         await config['database_connection'][config['database_name']][self.__collection_name__].update_one(
             self.__class__._get_fetch_filter({"_id": self.__id_marshaller__(self.id)}),
             {"$set": payload},
         )
-        await self.after_update()
+        if not create:
+            await self.after_update()
         await self.after_save()
         return self
 
